@@ -22,13 +22,13 @@
 #endif
 
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 #include <tqvaluelist.h>
 #include <tqfile.h>
 #include <tqtextstream.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 // This is just needed for i18n().  Once I figure out how to handle i18n
 // without using this macro directly, I'll be freed of KDE dependency.
 
@@ -519,7 +519,7 @@ namespace reports {
 
           // if we have a locale() then use its date formatter
           if ( TDEGlobal::locale() && ! data.isEmpty() ) {
-            TQDate qd = TQDate::fromString ( data, Qt::ISODate );
+            TQDate qd = TQDate::fromString ( data, TQt::ISODate );
             data = TDEGlobal::locale()->formatDate ( qd, true );
           }
           result += TQString ( "<td class=\"left\">%1</td>" ).arg ( data );
