@@ -18,7 +18,7 @@
 #define KMYMONEYDATEINPUT_H
 
 // ----------------------------------------------------------------------------
-// QT Includes
+// TQt Includes
 
 #include <tqwidget.h>
 #include <tqlineedit.h>
@@ -27,7 +27,7 @@
 #include <tqvbox.h>
 
 // ----------------------------------------------------------------------------
-// KDE Includes
+// TDE Includes
 
 #include <kdatepicker.h>
 class KPushButton;
@@ -45,7 +45,7 @@ class KPassivePopup;
   */
 class KMyMoneyDateEdit : public TQDateEdit
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KMyMoneyDateEdit(const TQDate& date, TQWidget *parent=0, const char *name=0) : TQDateEdit(date, parent, name) {}
@@ -63,7 +63,7 @@ protected:
   */
 class kMyMoneyDateInput : public TQHBox
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
